## tk create kustomization

Create or update a kustomization resource

### Synopsis


The kustomization source command generates a kustomization.kustomize.fluxcd.io resource for a given GitRepository source.
API spec: https://github.com/fluxcd/kustomize-controller/tree/master/docs/spec/v1alpha1

```
tk create kustomization [name] [flags]
```

### Examples

```
  # Create a kustomization from a source at a given path
  create kustomization contour \
    --source=contour \
    --path="./examples/contour/" \
    --prune="instance=contour" \
    --generate=true \
    --interval=10m \
    --validate=client \
    --health-check="Deployment/contour.projectcontour" \
    --health-check="DaemonSet/envoy.projectcontour" \
    --health-check-timeout=3m

  # Create a kustomization that depends on the previous one
  create kustomization webapp \
    --depends-on=contour \
    --source=webapp \
    --path="./deploy/overlays/dev" \
    --prune="env=dev,instance=webapp" \
    --interval=5m \
    --validate=client

```

### Options

```
      --depends-on stringArray          kustomization that must be ready before this kustomization can be applied
      --generate                        generate the kustomization.yaml for all the Kubernetes manifests in the specified path and sub-directories
      --health-check stringArray        workload to be included in the health assessment, in the format '<kind>/<name>.<namespace>'
      --health-check-timeout duration   timeout of health checking operations (default 2m0s)
  -h, --help                            help for kustomization
      --path string                     path to the directory containing the kustomization file (default "./")
      --prune string                    label selector used for garbage collection
      --source string                   GitRepository name
      --validate string                 validate the manifests before applying them on the cluster, can be 'client' or 'server'
```

### Options inherited from parent commands

```
      --components strings   list of components, accepts comma-separated values (default [source-controller,kustomize-controller])
      --interval duration    source sync interval (default 1m0s)
      --kubeconfig string    path to the kubeconfig file (default "~/.kube/config")
      --namespace string     the namespace scope for this operation (default "gitops-system")
      --timeout duration     timeout for this operation (default 5m0s)
      --verbose              print generated objects
```

### SEE ALSO

* [tk create](tk_create.md)	 - Create commands

###### Auto generated by spf13/cobra on 30-Apr-2020
